@@ -1,13 +1,27 @@
 import markdown
 from xhtml2pdf import pisa 
 
-def convert_md_to_pdf(input_md_filepath, output_pdf_filename):
+def convert(input_md_filepath, output_pdf_filename=None):
+    """Simply convert an md file to pdf. You can choose the output name,
+    but the default is the name of the input. 
 
+    Args:
+        input_md_filepath (str)
+        output_pdf_filename (str, optional)
+
+    Returns:
+        [Boolean]: False means success and True means errors.
+    """
+    
     with open(input_md_filepath, "r", encoding="utf-8") as input_file:
         text = input_file.read()
 
     source_html = markdown.markdown(text)
 
+
+    if(output_pdf_filename == None):
+        str_split = output_pdf_filename.split('.')
+        output_pdf_filename = str_split[0] + '.pdf'
     # open output file for writing (truncated binary)
     result_file = open(output_pdf_filename, "w+b")
 
